# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.social_sign_in_request import SocialSignInRequest

class TestSocialSignInRequest(unittest.TestCase):
    """SocialSignInRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SocialSignInRequest:
        """Test SocialSignInRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SocialSignInRequest`
        """
        model = SocialSignInRequest()
        if include_optional:
            return SocialSignInRequest(
                callback_url = '',
                new_user_callback_url = '',
                error_callback_url = '',
                provider = '',
                disable_redirect = True,
                id_token = better_auth.models.social_sign_in_request_id_token.socialSignIn_request_idToken(
                    token = '', 
                    nonce = '', 
                    access_token = '', 
                    refresh_token = '', 
                    expires_at = 1.337, ),
                scopes = [
                    null
                    ],
                request_sign_up = True,
                login_hint = '',
                additional_data = ''
            )
        else:
            return SocialSignInRequest(
                provider = '',
        )
        """

    def testSocialSignInRequest(self):
        """Test SocialSignInRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.generate_passkey_registration_options200_response import GeneratePasskeyRegistrationOptions200Response

class TestGeneratePasskeyRegistrationOptions200Response(unittest.TestCase):
    """GeneratePasskeyRegistrationOptions200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeneratePasskeyRegistrationOptions200Response:
        """Test GeneratePasskeyRegistrationOptions200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeneratePasskeyRegistrationOptions200Response`
        """
        model = GeneratePasskeyRegistrationOptions200Response()
        if include_optional:
            return GeneratePasskeyRegistrationOptions200Response(
                challenge = '',
                rp = better_auth.models.generate_passkey_registration_options_200_response_rp.generatePasskeyRegistrationOptions_200_response_rp(
                    name = '', 
                    id = '', ),
                user = better_auth.models.generate_passkey_registration_options_200_response_user.generatePasskeyRegistrationOptions_200_response_user(
                    id = '', 
                    name = '', 
                    display_name = '', ),
                pub_key_cred_params = [
                    better_auth.models.generate_passkey_registration_options_200_response_pub_key_cred_params_inner.generatePasskeyRegistrationOptions_200_response_pubKeyCredParams_inner(
                        type = '', 
                        alg = 1.337, )
                    ],
                timeout = 1.337,
                exclude_credentials = [
                    better_auth.models.generate_passkey_registration_options_200_response_exclude_credentials_inner.generatePasskeyRegistrationOptions_200_response_excludeCredentials_inner(
                        id = '', 
                        type = '', 
                        transports = [
                            ''
                            ], )
                    ],
                authenticator_selection = better_auth.models.generate_passkey_registration_options_200_response_authenticator_selection.generatePasskeyRegistrationOptions_200_response_authenticatorSelection(
                    authenticator_attachment = '', 
                    require_resident_key = True, 
                    user_verification = '', ),
                attestation = '',
                extensions = None
            )
        else:
            return GeneratePasskeyRegistrationOptions200Response(
        )
        """

    def testGeneratePasskeyRegistrationOptions200Response(self):
        """Test GeneratePasskeyRegistrationOptions200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class ApiKeyCreatePost200Response(BaseModel):
    """
    ApiKeyCreatePost200Response
    """ # noqa: E501
    id: StrictStr = Field(description="Unique identifier of the API key")
    created_at: datetime = Field(description="Creation timestamp", alias="createdAt")
    updated_at: datetime = Field(description="Last update timestamp", alias="updatedAt")
    name: Optional[StrictStr] = Field(default=None, description="Name of the API key")
    prefix: Optional[StrictStr] = Field(default=None, description="Prefix of the API key")
    start: Optional[StrictStr] = Field(default=None, description="Starting characters of the key (if configured)")
    key: StrictStr = Field(description="The full API key (only returned on creation)")
    enabled: StrictBool = Field(description="Whether the key is enabled")
    expires_at: Optional[datetime] = Field(default=None, description="Expiration timestamp", alias="expiresAt")
    user_id: StrictStr = Field(description="ID of the user owning the key", alias="userId")
    last_refill_at: Optional[datetime] = Field(default=None, description="Last refill timestamp", alias="lastRefillAt")
    last_request: Optional[datetime] = Field(default=None, description="Last request timestamp", alias="lastRequest")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Metadata associated with the key")
    rate_limit_max: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Maximum requests in time window", alias="rateLimitMax")
    rate_limit_time_window: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Rate limit time window in milliseconds", alias="rateLimitTimeWindow")
    remaining: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Remaining requests")
    refill_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Amount to refill", alias="refillAmount")
    refill_interval: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Refill interval in milliseconds", alias="refillInterval")
    rate_limit_enabled: StrictBool = Field(description="Whether rate limiting is enabled", alias="rateLimitEnabled")
    request_count: Union[StrictFloat, StrictInt] = Field(description="Current request count in window", alias="requestCount")
    permissions: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="Permissions associated with the key")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "name", "prefix", "start", "key", "enabled", "expiresAt", "userId", "lastRefillAt", "lastRequest", "metadata", "rateLimitMax", "rateLimitTimeWindow", "remaining", "refillAmount", "refillInterval", "rateLimitEnabled", "requestCount", "permissions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiKeyCreatePost200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiKeyCreatePost200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "name": obj.get("name"),
            "prefix": obj.get("prefix"),
            "start": obj.get("start"),
            "key": obj.get("key"),
            "enabled": obj.get("enabled"),
            "expiresAt": obj.get("expiresAt"),
            "userId": obj.get("userId"),
            "lastRefillAt": obj.get("lastRefillAt"),
            "lastRequest": obj.get("lastRequest"),
            "metadata": obj.get("metadata"),
            "rateLimitMax": obj.get("rateLimitMax"),
            "rateLimitTimeWindow": obj.get("rateLimitTimeWindow"),
            "remaining": obj.get("remaining"),
            "refillAmount": obj.get("refillAmount"),
            "refillInterval": obj.get("refillInterval"),
            "rateLimitEnabled": obj.get("rateLimitEnabled"),
            "requestCount": obj.get("requestCount"),
            "permissions": obj.get("permissions")
        })
        return _obj





# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.passkey_api import PasskeyApi


class TestPasskeyApi(unittest.TestCase):
    """PasskeyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasskeyApi()

    def tearDown(self) -> None:
        pass

    def test_generate_passkey_registration_options(self) -> None:
        """Test case for generate_passkey_registration_options

        """
        pass

    def test_passkey_delete_passkey_post(self) -> None:
        """Test case for passkey_delete_passkey_post

        """
        pass

    def test_passkey_generate_authenticate_options(self) -> None:
        """Test case for passkey_generate_authenticate_options

        """
        pass

    def test_passkey_list_user_passkeys_get(self) -> None:
        """Test case for passkey_list_user_passkeys_get

        """
        pass

    def test_passkey_update_passkey_post(self) -> None:
        """Test case for passkey_update_passkey_post

        """
        pass

    def test_passkey_verify_authentication(self) -> None:
        """Test case for passkey_verify_authentication

        """
        pass

    def test_passkey_verify_registration(self) -> None:
        """Test case for passkey_verify_registration

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.social_sign_in403_response import SocialSignIn403Response

class TestSocialSignIn403Response(unittest.TestCase):
    """SocialSignIn403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SocialSignIn403Response:
        """Test SocialSignIn403Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SocialSignIn403Response`
        """
        model = SocialSignIn403Response()
        if include_optional:
            return SocialSignIn403Response(
                message = ''
            )
        else:
            return SocialSignIn403Response(
        )
        """

    def testSocialSignIn403Response(self):
        """Test SocialSignIn403Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.two_factor_verify_backup_code_post200_response import TwoFactorVerifyBackupCodePost200Response

class TestTwoFactorVerifyBackupCodePost200Response(unittest.TestCase):
    """TwoFactorVerifyBackupCodePost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TwoFactorVerifyBackupCodePost200Response:
        """Test TwoFactorVerifyBackupCodePost200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TwoFactorVerifyBackupCodePost200Response`
        """
        model = TwoFactorVerifyBackupCodePost200Response()
        if include_optional:
            return TwoFactorVerifyBackupCodePost200Response(
                user = better_auth.models._two_factor_verify_backup_code_post_200_response_user._two_factor_verify_backup_code_post_200_response_user(
                    id = '', 
                    email = '', 
                    email_verified = True, 
                    name = '', 
                    image = '', 
                    two_factor_enabled = True, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                session = better_auth.models._two_factor_verify_backup_code_post_200_response_session._two_factor_verify_backup_code_post_200_response_session(
                    token = '', 
                    user_id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return TwoFactorVerifyBackupCodePost200Response(
                user = better_auth.models._two_factor_verify_backup_code_post_200_response_user._two_factor_verify_backup_code_post_200_response_user(
                    id = '', 
                    email = '', 
                    email_verified = True, 
                    name = '', 
                    image = '', 
                    two_factor_enabled = True, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                session = better_auth.models._two_factor_verify_backup_code_post_200_response_session._two_factor_verify_backup_code_post_200_response_session(
                    token = '', 
                    user_id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testTwoFactorVerifyBackupCodePost200Response(self):
        """Test TwoFactorVerifyBackupCodePost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_account_info_get(self) -> None:
        """Test case for account_info_get

        """
        pass

    def test_change_email(self) -> None:
        """Test case for change_email

        """
        pass

    def test_change_password(self) -> None:
        """Test case for change_password

        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        """
        pass

    def test_delete_user_callback_get(self) -> None:
        """Test case for delete_user_callback_get

        """
        pass

    def test_error_get(self) -> None:
        """Test case for error_get

        """
        pass

    def test_forget_password(self) -> None:
        """Test case for forget_password

        """
        pass

    def test_get_access_token_post(self) -> None:
        """Test case for get_access_token_post

        """
        pass

    def test_get_session(self) -> None:
        """Test case for get_session

        """
        pass

    def test_link_social_account(self) -> None:
        """Test case for link_social_account

        """
        pass

    def test_list_user_accounts(self) -> None:
        """Test case for list_user_accounts

        """
        pass

    def test_list_user_sessions(self) -> None:
        """Test case for list_user_sessions

        """
        pass

    def test_ok_get(self) -> None:
        """Test case for ok_get

        """
        pass

    def test_refresh_token_post(self) -> None:
        """Test case for refresh_token_post

        """
        pass

    def test_reset_password(self) -> None:
        """Test case for reset_password

        """
        pass

    def test_reset_password_callback(self) -> None:
        """Test case for reset_password_callback

        """
        pass

    def test_revoke_other_sessions_post(self) -> None:
        """Test case for revoke_other_sessions_post

        """
        pass

    def test_revoke_session_post(self) -> None:
        """Test case for revoke_session_post

        """
        pass

    def test_revoke_sessions_post(self) -> None:
        """Test case for revoke_sessions_post

        """
        pass

    def test_send_verification_email(self) -> None:
        """Test case for send_verification_email

        """
        pass

    def test_sign_in_email(self) -> None:
        """Test case for sign_in_email

        """
        pass

    def test_sign_out(self) -> None:
        """Test case for sign_out

        """
        pass

    def test_sign_up_with_email_and_password(self) -> None:
        """Test case for sign_up_with_email_and_password

        """
        pass

    def test_social_sign_in(self) -> None:
        """Test case for social_sign_in

        """
        pass

    def test_unlink_account_post(self) -> None:
        """Test case for unlink_account_post

        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        """
        pass

    def test_verify_email_get(self) -> None:
        """Test case for verify_email_get

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.1-beta11"

# Define package exports
__all__ = [
    "AdminApi",
    "ApiKeyApi",
    "DefaultApi",
    "OneTapApi",
    "PasskeyApi",
    "StripeApi",
    "TwoFactorApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Account",
    "AccountInfoGet200Response",
    "AccountInfoGet200ResponseUser",
    "AdminBanUserRequest",
    "AdminCreateUserRequest",
    "AdminHasPermission200Response",
    "AdminHasPermissionRequest",
    "AdminListUserSessions200Response",
    "AdminListUserSessionsRequest",
    "AdminListUsers200Response",
    "AdminRevokeUserSessionRequest",
    "AdminSetUserPasswordRequest",
    "AdminSetUserRoleRequest",
    "AdminUpdateUserRequest",
    "ApiKeyCreatePost200Response",
    "ApiKeyCreatePostRequest",
    "ApiKeyDeletePost200Response",
    "ApiKeyDeletePostRequest",
    "ApiKeyGetGet200Response",
    "ApiKeyListGet200ResponseInner",
    "ApiKeyUpdatePostRequest",
    "Apikey",
    "ChangeEmail200Response",
    "ChangeEmailRequest",
    "ChangePassword200Response",
    "ChangePasswordRequest",
    "DeleteUser200Response",
    "DeleteUserCallbackGet200Response",
    "DeleteUserRequest",
    "ForgetPassword200Response",
    "ForgetPasswordRequest",
    "GeneratePasskeyRegistrationOptions200Response",
    "GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection",
    "GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner",
    "GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner",
    "GeneratePasskeyRegistrationOptions200ResponseRp",
    "GeneratePasskeyRegistrationOptions200ResponseUser",
    "GetSession200Response",
    "LinkSocialAccount200Response",
    "LinkSocialAccountRequest",
    "LinkSocialAccountRequestIdToken",
    "ListUserAccounts200ResponseInner",
    "OkGet200Response",
    "OneTapCallbackPost200Response",
    "OneTapCallbackPostRequest",
    "Passkey",
    "PasskeyDeletePasskeyPost200Response",
    "PasskeyDeletePasskeyPostRequest",
    "PasskeyGenerateAuthenticateOptions200Response",
    "PasskeyUpdatePasskeyPost200Response",
    "PasskeyUpdatePasskeyPostRequest",
    "PasskeyVerifyAuthenticationRequest",
    "PasskeyVerifyRegistrationRequest",
    "RefreshTokenPost200Response",
    "RefreshTokenPostRequest",
    "ResetPassword200Response",
    "ResetPasswordCallback200Response",
    "ResetPasswordRequest",
    "RevokeOtherSessionsPost200Response",
    "RevokeSessionPost200Response",
    "RevokeSessionPostRequest",
    "RevokeSessionsPost200Response",
    "SendVerificationEmail200Response",
    "SendVerificationEmail400Response",
    "SendVerificationEmailRequest",
    "Session",
    "SignInEmail200Response",
    "SignInEmailRequest",
    "SignOut200Response",
    "SignUpWithEmailAndPassword200Response",
    "SignUpWithEmailAndPassword200ResponseUser",
    "SignUpWithEmailAndPasswordRequest",
    "SocialSignIn200Response",
    "SocialSignIn400Response",
    "SocialSignIn403Response",
    "SocialSignInRequest",
    "SocialSignInRequestIdToken",
    "TwoFactor",
    "TwoFactorEnablePost200Response",
    "TwoFactorEnablePostRequest",
    "TwoFactorGenerateBackupCodesPost200Response",
    "TwoFactorGenerateBackupCodesPostRequest",
    "TwoFactorGetTotpUriPost200Response",
    "TwoFactorGetTotpUriPostRequest",
    "TwoFactorVerifyBackupCodePost200Response",
    "TwoFactorVerifyBackupCodePost200ResponseSession",
    "TwoFactorVerifyBackupCodePost200ResponseUser",
    "TwoFactorVerifyBackupCodePostRequest",
    "TwoFactorVerifyOtpPost200Response",
    "TwoFactorVerifyOtpPost200ResponseUser",
    "TwoFactorVerifyOtpPostRequest",
    "TwoFactorVerifyTotpPostRequest",
    "UnlinkAccountPostRequest",
    "UpdateUser200Response",
    "UpdateUserRequest",
    "User",
    "Verification",
    "VerifyEmailGet200Response",
]

# import apis into sdk package
from better_auth.api.admin_api import AdminApi as AdminApi
from better_auth.api.api_key_api import ApiKeyApi as ApiKeyApi
from better_auth.api.default_api import DefaultApi as DefaultApi
from better_auth.api.one_tap_api import OneTapApi as OneTapApi
from better_auth.api.passkey_api import PasskeyApi as PasskeyApi
from better_auth.api.stripe_api import StripeApi as StripeApi
from better_auth.api.two_factor_api import TwoFactorApi as TwoFactorApi

# import ApiClient
from better_auth.api_response import ApiResponse as ApiResponse
from better_auth.api_client import ApiClient as ApiClient
from better_auth.configuration import Configuration as Configuration
from better_auth.exceptions import OpenApiException as OpenApiException
from better_auth.exceptions import ApiTypeError as ApiTypeError
from better_auth.exceptions import ApiValueError as ApiValueError
from better_auth.exceptions import ApiKeyError as ApiKeyError
from better_auth.exceptions import ApiAttributeError as ApiAttributeError
from better_auth.exceptions import ApiException as ApiException

# import models into sdk package
from better_auth.models.account import Account as Account
from better_auth.models.account_info_get200_response import AccountInfoGet200Response as AccountInfoGet200Response
from better_auth.models.account_info_get200_response_user import AccountInfoGet200ResponseUser as AccountInfoGet200ResponseUser
from better_auth.models.admin_ban_user_request import AdminBanUserRequest as AdminBanUserRequest
from better_auth.models.admin_create_user_request import AdminCreateUserRequest as AdminCreateUserRequest
from better_auth.models.admin_has_permission200_response import AdminHasPermission200Response as AdminHasPermission200Response
from better_auth.models.admin_has_permission_request import AdminHasPermissionRequest as AdminHasPermissionRequest
from better_auth.models.admin_list_user_sessions200_response import AdminListUserSessions200Response as AdminListUserSessions200Response
from better_auth.models.admin_list_user_sessions_request import AdminListUserSessionsRequest as AdminListUserSessionsRequest
from better_auth.models.admin_list_users200_response import AdminListUsers200Response as AdminListUsers200Response
from better_auth.models.admin_revoke_user_session_request import AdminRevokeUserSessionRequest as AdminRevokeUserSessionRequest
from better_auth.models.admin_set_user_password_request import AdminSetUserPasswordRequest as AdminSetUserPasswordRequest
from better_auth.models.admin_set_user_role_request import AdminSetUserRoleRequest as AdminSetUserRoleRequest
from better_auth.models.admin_update_user_request import AdminUpdateUserRequest as AdminUpdateUserRequest
from better_auth.models.api_key_create_post200_response import ApiKeyCreatePost200Response as ApiKeyCreatePost200Response
from better_auth.models.api_key_create_post_request import ApiKeyCreatePostRequest as ApiKeyCreatePostRequest
from better_auth.models.api_key_delete_post200_response import ApiKeyDeletePost200Response as ApiKeyDeletePost200Response
from better_auth.models.api_key_delete_post_request import ApiKeyDeletePostRequest as ApiKeyDeletePostRequest
from better_auth.models.api_key_get_get200_response import ApiKeyGetGet200Response as ApiKeyGetGet200Response
from better_auth.models.api_key_list_get200_response_inner import ApiKeyListGet200ResponseInner as ApiKeyListGet200ResponseInner
from better_auth.models.api_key_update_post_request import ApiKeyUpdatePostRequest as ApiKeyUpdatePostRequest
from better_auth.models.apikey import Apikey as Apikey
from better_auth.models.change_email200_response import ChangeEmail200Response as ChangeEmail200Response
from better_auth.models.change_email_request import ChangeEmailRequest as ChangeEmailRequest
from better_auth.models.change_password200_response import ChangePassword200Response as ChangePassword200Response
from better_auth.models.change_password_request import ChangePasswordRequest as ChangePasswordRequest
from better_auth.models.delete_user200_response import DeleteUser200Response as DeleteUser200Response
from better_auth.models.delete_user_callback_get200_response import DeleteUserCallbackGet200Response as DeleteUserCallbackGet200Response
from better_auth.models.delete_user_request import DeleteUserRequest as DeleteUserRequest
from better_auth.models.forget_password200_response import ForgetPassword200Response as ForgetPassword200Response
from better_auth.models.forget_password_request import ForgetPasswordRequest as ForgetPasswordRequest
from better_auth.models.generate_passkey_registration_options200_response import GeneratePasskeyRegistrationOptions200Response as GeneratePasskeyRegistrationOptions200Response
from better_auth.models.generate_passkey_registration_options200_response_authenticator_selection import GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection as GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection
from better_auth.models.generate_passkey_registration_options200_response_exclude_credentials_inner import GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner as GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner
from better_auth.models.generate_passkey_registration_options200_response_pub_key_cred_params_inner import GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner as GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner
from better_auth.models.generate_passkey_registration_options200_response_rp import GeneratePasskeyRegistrationOptions200ResponseRp as GeneratePasskeyRegistrationOptions200ResponseRp
from better_auth.models.generate_passkey_registration_options200_response_user import GeneratePasskeyRegistrationOptions200ResponseUser as GeneratePasskeyRegistrationOptions200ResponseUser
from better_auth.models.get_session200_response import GetSession200Response as GetSession200Response
from better_auth.models.link_social_account200_response import LinkSocialAccount200Response as LinkSocialAccount200Response
from better_auth.models.link_social_account_request import LinkSocialAccountRequest as LinkSocialAccountRequest
from better_auth.models.link_social_account_request_id_token import LinkSocialAccountRequestIdToken as LinkSocialAccountRequestIdToken
from better_auth.models.list_user_accounts200_response_inner import ListUserAccounts200ResponseInner as ListUserAccounts200ResponseInner
from better_auth.models.ok_get200_response import OkGet200Response as OkGet200Response
from better_auth.models.one_tap_callback_post200_response import OneTapCallbackPost200Response as OneTapCallbackPost200Response
from better_auth.models.one_tap_callback_post_request import OneTapCallbackPostRequest as OneTapCallbackPostRequest
from better_auth.models.passkey import Passkey as Passkey
from better_auth.models.passkey_delete_passkey_post200_response import PasskeyDeletePasskeyPost200Response as PasskeyDeletePasskeyPost200Response
from better_auth.models.passkey_delete_passkey_post_request import PasskeyDeletePasskeyPostRequest as PasskeyDeletePasskeyPostRequest
from better_auth.models.passkey_generate_authenticate_options200_response import PasskeyGenerateAuthenticateOptions200Response as PasskeyGenerateAuthenticateOptions200Response
from better_auth.models.passkey_update_passkey_post200_response import PasskeyUpdatePasskeyPost200Response as PasskeyUpdatePasskeyPost200Response
from better_auth.models.passkey_update_passkey_post_request import PasskeyUpdatePasskeyPostRequest as PasskeyUpdatePasskeyPostRequest
from better_auth.models.passkey_verify_authentication_request import PasskeyVerifyAuthenticationRequest as PasskeyVerifyAuthenticationRequest
from better_auth.models.passkey_verify_registration_request import PasskeyVerifyRegistrationRequest as PasskeyVerifyRegistrationRequest
from better_auth.models.refresh_token_post200_response import RefreshTokenPost200Response as RefreshTokenPost200Response
from better_auth.models.refresh_token_post_request import RefreshTokenPostRequest as RefreshTokenPostRequest
from better_auth.models.reset_password200_response import ResetPassword200Response as ResetPassword200Response
from better_auth.models.reset_password_callback200_response import ResetPasswordCallback200Response as ResetPasswordCallback200Response
from better_auth.models.reset_password_request import ResetPasswordRequest as ResetPasswordRequest
from better_auth.models.revoke_other_sessions_post200_response import RevokeOtherSessionsPost200Response as RevokeOtherSessionsPost200Response
from better_auth.models.revoke_session_post200_response import RevokeSessionPost200Response as RevokeSessionPost200Response
from better_auth.models.revoke_session_post_request import RevokeSessionPostRequest as RevokeSessionPostRequest
from better_auth.models.revoke_sessions_post200_response import RevokeSessionsPost200Response as RevokeSessionsPost200Response
from better_auth.models.send_verification_email200_response import SendVerificationEmail200Response as SendVerificationEmail200Response
from better_auth.models.send_verification_email400_response import SendVerificationEmail400Response as SendVerificationEmail400Response
from better_auth.models.send_verification_email_request import SendVerificationEmailRequest as SendVerificationEmailRequest
from better_auth.models.session import Session as Session
from better_auth.models.sign_in_email200_response import SignInEmail200Response as SignInEmail200Response
from better_auth.models.sign_in_email_request import SignInEmailRequest as SignInEmailRequest
from better_auth.models.sign_out200_response import SignOut200Response as SignOut200Response
from better_auth.models.sign_up_with_email_and_password200_response import SignUpWithEmailAndPassword200Response as SignUpWithEmailAndPassword200Response
from better_auth.models.sign_up_with_email_and_password200_response_user import SignUpWithEmailAndPassword200ResponseUser as SignUpWithEmailAndPassword200ResponseUser
from better_auth.models.sign_up_with_email_and_password_request import SignUpWithEmailAndPasswordRequest as SignUpWithEmailAndPasswordRequest
from better_auth.models.social_sign_in200_response import SocialSignIn200Response as SocialSignIn200Response
from better_auth.models.social_sign_in400_response import SocialSignIn400Response as SocialSignIn400Response
from better_auth.models.social_sign_in403_response import SocialSignIn403Response as SocialSignIn403Response
from better_auth.models.social_sign_in_request import SocialSignInRequest as SocialSignInRequest
from better_auth.models.social_sign_in_request_id_token import SocialSignInRequestIdToken as SocialSignInRequestIdToken
from better_auth.models.two_factor import TwoFactor as TwoFactor
from better_auth.models.two_factor_enable_post200_response import TwoFactorEnablePost200Response as TwoFactorEnablePost200Response
from better_auth.models.two_factor_enable_post_request import TwoFactorEnablePostRequest as TwoFactorEnablePostRequest
from better_auth.models.two_factor_generate_backup_codes_post200_response import TwoFactorGenerateBackupCodesPost200Response as TwoFactorGenerateBackupCodesPost200Response
from better_auth.models.two_factor_generate_backup_codes_post_request import TwoFactorGenerateBackupCodesPostRequest as TwoFactorGenerateBackupCodesPostRequest
from better_auth.models.two_factor_get_totp_uri_post200_response import TwoFactorGetTotpUriPost200Response as TwoFactorGetTotpUriPost200Response
from better_auth.models.two_factor_get_totp_uri_post_request import TwoFactorGetTotpUriPostRequest as TwoFactorGetTotpUriPostRequest
from better_auth.models.two_factor_verify_backup_code_post200_response import TwoFactorVerifyBackupCodePost200Response as TwoFactorVerifyBackupCodePost200Response
from better_auth.models.two_factor_verify_backup_code_post200_response_session import TwoFactorVerifyBackupCodePost200ResponseSession as TwoFactorVerifyBackupCodePost200ResponseSession
from better_auth.models.two_factor_verify_backup_code_post200_response_user import TwoFactorVerifyBackupCodePost200ResponseUser as TwoFactorVerifyBackupCodePost200ResponseUser
from better_auth.models.two_factor_verify_backup_code_post_request import TwoFactorVerifyBackupCodePostRequest as TwoFactorVerifyBackupCodePostRequest
from better_auth.models.two_factor_verify_otp_post200_response import TwoFactorVerifyOtpPost200Response as TwoFactorVerifyOtpPost200Response
from better_auth.models.two_factor_verify_otp_post200_response_user import TwoFactorVerifyOtpPost200ResponseUser as TwoFactorVerifyOtpPost200ResponseUser
from better_auth.models.two_factor_verify_otp_post_request import TwoFactorVerifyOtpPostRequest as TwoFactorVerifyOtpPostRequest
from better_auth.models.two_factor_verify_totp_post_request import TwoFactorVerifyTotpPostRequest as TwoFactorVerifyTotpPostRequest
from better_auth.models.unlink_account_post_request import UnlinkAccountPostRequest as UnlinkAccountPostRequest
from better_auth.models.update_user200_response import UpdateUser200Response as UpdateUser200Response
from better_auth.models.update_user_request import UpdateUserRequest as UpdateUserRequest
from better_auth.models.user import User as User
from better_auth.models.verification import Verification as Verification
from better_auth.models.verify_email_get200_response import VerifyEmailGet200Response as VerifyEmailGet200Response




# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.admin_create_user_request import AdminCreateUserRequest

class TestAdminCreateUserRequest(unittest.TestCase):
    """AdminCreateUserRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminCreateUserRequest:
        """Test AdminCreateUserRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminCreateUserRequest`
        """
        model = AdminCreateUserRequest()
        if include_optional:
            return AdminCreateUserRequest(
                email = '',
                password = '',
                name = '',
                role = '',
                data = ''
            )
        else:
            return AdminCreateUserRequest(
                email = '',
                password = '',
                name = '',
        )
        """

    def testAdminCreateUserRequest(self):
        """Test AdminCreateUserRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from better_auth.models.generate_passkey_registration_options200_response_authenticator_selection import GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection
from better_auth.models.generate_passkey_registration_options200_response_exclude_credentials_inner import GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner
from better_auth.models.generate_passkey_registration_options200_response_pub_key_cred_params_inner import GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner
from better_auth.models.generate_passkey_registration_options200_response_rp import GeneratePasskeyRegistrationOptions200ResponseRp
from better_auth.models.generate_passkey_registration_options200_response_user import GeneratePasskeyRegistrationOptions200ResponseUser
from typing import Optional, Set
from typing_extensions import Self

class GeneratePasskeyRegistrationOptions200Response(BaseModel):
    """
    GeneratePasskeyRegistrationOptions200Response
    """ # noqa: E501
    challenge: Optional[StrictStr] = None
    rp: Optional[GeneratePasskeyRegistrationOptions200ResponseRp] = None
    user: Optional[GeneratePasskeyRegistrationOptions200ResponseUser] = None
    pub_key_cred_params: Optional[List[GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner]] = Field(default=None, alias="pubKeyCredParams")
    timeout: Optional[Union[StrictFloat, StrictInt]] = None
    exclude_credentials: Optional[List[GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner]] = Field(default=None, alias="excludeCredentials")
    authenticator_selection: Optional[GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection] = Field(default=None, alias="authenticatorSelection")
    attestation: Optional[StrictStr] = None
    extensions: Optional[Dict[str, Any]] = None
    __properties: ClassVar[List[str]] = ["challenge", "rp", "user", "pubKeyCredParams", "timeout", "excludeCredentials", "authenticatorSelection", "attestation", "extensions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GeneratePasskeyRegistrationOptions200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of rp
        if self.rp:
            _dict['rp'] = self.rp.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in pub_key_cred_params (list)
        _items = []
        if self.pub_key_cred_params:
            for _item_pub_key_cred_params in self.pub_key_cred_params:
                if _item_pub_key_cred_params:
                    _items.append(_item_pub_key_cred_params.to_dict())
            _dict['pubKeyCredParams'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in exclude_credentials (list)
        _items = []
        if self.exclude_credentials:
            for _item_exclude_credentials in self.exclude_credentials:
                if _item_exclude_credentials:
                    _items.append(_item_exclude_credentials.to_dict())
            _dict['excludeCredentials'] = _items
        # override the default output from pydantic by calling `to_dict()` of authenticator_selection
        if self.authenticator_selection:
            _dict['authenticatorSelection'] = self.authenticator_selection.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GeneratePasskeyRegistrationOptions200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "challenge": obj.get("challenge"),
            "rp": GeneratePasskeyRegistrationOptions200ResponseRp.from_dict(obj["rp"]) if obj.get("rp") is not None else None,
            "user": GeneratePasskeyRegistrationOptions200ResponseUser.from_dict(obj["user"]) if obj.get("user") is not None else None,
            "pubKeyCredParams": [GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner.from_dict(_item) for _item in obj["pubKeyCredParams"]] if obj.get("pubKeyCredParams") is not None else None,
            "timeout": obj.get("timeout"),
            "excludeCredentials": [GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner.from_dict(_item) for _item in obj["excludeCredentials"]] if obj.get("excludeCredentials") is not None else None,
            "authenticatorSelection": GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection.from_dict(obj["authenticatorSelection"]) if obj.get("authenticatorSelection") is not None else None,
            "attestation": obj.get("attestation"),
            "extensions": obj.get("extensions")
        })
        return _obj





# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class ApiKeyGetGet200Response(BaseModel):
    """
    ApiKeyGetGet200Response
    """ # noqa: E501
    id: StrictStr = Field(description="ID")
    name: Optional[StrictStr] = Field(default=None, description="The name of the key")
    start: Optional[StrictStr] = Field(default=None, description="Shows the first few characters of the API key, including the prefix. This allows you to show those few characters in the UI to make it easier for users to identify the API key.")
    prefix: Optional[StrictStr] = Field(default=None, description="The API Key prefix. Stored as plain text.")
    user_id: StrictStr = Field(description="The owner of the user id", alias="userId")
    refill_interval: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The interval in milliseconds between refills of the `remaining` count. Example: 3600000 // refill every hour (3600000ms = 1h)", alias="refillInterval")
    refill_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The amount to refill", alias="refillAmount")
    last_refill_at: Optional[datetime] = Field(default=None, description="The last refill date", alias="lastRefillAt")
    enabled: StrictBool = Field(description="Sets if key is enabled or disabled")
    rate_limit_enabled: StrictBool = Field(description="Whether the key has rate limiting enabled", alias="rateLimitEnabled")
    rate_limit_time_window: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The duration in milliseconds", alias="rateLimitTimeWindow")
    rate_limit_max: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Maximum amount of requests allowed within a window", alias="rateLimitMax")
    request_count: Union[StrictFloat, StrictInt] = Field(description="The number of requests made within the rate limit time window", alias="requestCount")
    remaining: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Remaining requests (every time api key is used this should updated and should be updated on refill as well)")
    last_request: Optional[datetime] = Field(default=None, description="When last request occurred", alias="lastRequest")
    expires_at: Optional[datetime] = Field(default=None, description="Expiry date of a key", alias="expiresAt")
    created_at: datetime = Field(description="created at", alias="createdAt")
    updated_at: datetime = Field(description="updated at", alias="updatedAt")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Extra metadata about the apiKey")
    permissions: Optional[StrictStr] = Field(default=None, description="Permissions for the api key (stored as JSON string)")
    __properties: ClassVar[List[str]] = ["id", "name", "start", "prefix", "userId", "refillInterval", "refillAmount", "lastRefillAt", "enabled", "rateLimitEnabled", "rateLimitTimeWindow", "rateLimitMax", "requestCount", "remaining", "lastRequest", "expiresAt", "createdAt", "updatedAt", "metadata", "permissions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiKeyGetGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiKeyGetGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "start": obj.get("start"),
            "prefix": obj.get("prefix"),
            "userId": obj.get("userId"),
            "refillInterval": obj.get("refillInterval"),
            "refillAmount": obj.get("refillAmount"),
            "lastRefillAt": obj.get("lastRefillAt"),
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else True,
            "rateLimitEnabled": obj.get("rateLimitEnabled"),
            "rateLimitTimeWindow": obj.get("rateLimitTimeWindow"),
            "rateLimitMax": obj.get("rateLimitMax"),
            "requestCount": obj.get("requestCount"),
            "remaining": obj.get("remaining"),
            "lastRequest": obj.get("lastRequest"),
            "expiresAt": obj.get("expiresAt"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "metadata": obj.get("metadata"),
            "permissions": obj.get("permissions")
        })
        return _obj


